/***************************************************************************
                          kgeoToolbarHandling.cpp  -  description
                             -------------------
    begin                : Sun Sep 17 2000
    copyright            : (C) 2000 by Marc Bartsch
    email                : marc.bartsch@topmail.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version. keuklid                                  *
 *                                                                         *
 ***************************************************************************/

#include "kgeo.h"

void KGeoApp::toolBar2Clicked( int x )
{
 	newObject = 0;
	disconnectAll();
	deselectParamObjects();
	currentButtonID = x;

	switch ( x )
	{
		case ID_buttonMoveGrid:
			drawingMode = ID_drawingModeMovingGrid;
			canvas->setCursor( sizeAllCursor );
	  	statusBar()->changeItem(  i18n( "Move the underlying grid" ), 1 );
			startMoveGridMode();
			canvas->setStartup( false );
			break;
		case ID_buttonPoint:
			newObject = new Point();
			startConstructionMode( i18n( "Draw a point" ) );
			break;
		case ID_buttonSegment:
			newObject = new Segment();
			startConstructionMode(  i18n( "Draw a segment between two points" ) );
			break;
		case ID_buttonLine:
			newObject = new Line();
			startConstructionMode(  i18n( "Draw a line" ) );
			break;
		case ID_buttonPointOnLine:
			newObject = new PointOnLine();
			startConstructionMode(  i18n( "Draw  a point on a line or circle" ) );
			break;
		case ID_buttonPointOfConc:
			newObject = new PointOfConc();
			startConstructionMode(  i18n( "Draw the point of concurrency of two lines or two segments" ) );
			break;
		case ID_buttonBisection:
			newObject = new Bisection();
			startConstructionMode(  i18n( "Draw the bisection of two points" ) );
			break;		
		case ID_buttonMirrorPoint:
			newObject = new MirrorPoint();
			startConstructionMode(  i18n( "Draw mirror point of point/point or point/line" ) );
			break;		
		case ID_buttonTriangle:
			newObject = new Triangle();
			startConstructionMode(  i18n( "Draw a triangle" ) );
			break;
		case ID_buttonCircle:
			newObject = new Circle();
			startConstructionMode(  i18n( "Draw a cricle" ) );
			break;
		case ID_buttonBaseCircle:
			newObject = new FixedCircle();
			startConstructionMode(  i18n( "Draw a circle with a fixed diameter" ) );
			break;
		case ID_buttonArc:
			newObject = new Arc();
			startConstructionMode(  i18n( "Draw an arc" ) );
			break;
		case ID_buttonVector:
			newObject = new Vector();
			startConstructionMode(  i18n( "Draw a vector" )  );
			break;
		case ID_buttonRay:
			newObject = new Ray();
			startConstructionMode(  i18n( "Draw a ray" ) );
			break;
		case ID_buttonParallel:
			newObject = new Parallel();
			startConstructionMode(  i18n( "Draw a parallel of a line" ) );
			break;
		case ID_buttonPerpendicular:
			newObject = new Perpendicular();
			startConstructionMode(  i18n( "Draw the perpendicular line of a line through a point" ) );
			break;
		case ID_buttonMove:
			newObject = new Move();
			startConstructionMode(  i18n( "Move a point using a vector" ) );
			break;
		case ID_buttonRotation:
			newObject = new Rotation();
			startConstructionMode(  i18n( "Rotate one point around another using a certain arc" ) );
			break;
		case ID_buttonEraser:
			newObject = new Eraser();
			startConstructionMode(  i18n( "Erase an object and all of its child objects" ) );
			break;
		case ID_buttonAttacher:
			newObject = new Attacher();
			startConstructionMode(  i18n( "Attach a point on a line/circle" ) );
			break;
		case ID_buttonTracer:
			newObject = new Tracer();
			startConstructionMode(  i18n( "Toggle trace" ) );
			break;
		case ID_buttonText:
			newObject = new Text();
			startConstructionMode(  i18n( "Add a text field" ) );
			break;
		case ID_buttonDistance:
			newObject = new Distance();
			startConstructionMode(  i18n( "Measure the distance between two points" ) );
			break;
		case ID_buttonAngle:
			newObject = new Angle();
			startConstructionMode(  i18n( "Measure an angle in degree" ) );
			break;
		case ID_buttonArea:
			newObject = new Area();
			startConstructionMode(  i18n( "Measure the area of a circle" ) );
			break;
		case ID_buttonSlope:
			newObject = new Slope();
			startConstructionMode(  i18n( "Measure the slope between two points" ) );
			break;
		case ID_buttonCircumference:
			newObject = new Circumference();
			startConstructionMode(  i18n( "Measure the circumference of a circle" ) );
			break;
		case ID_buttonBlack:
			newObject = new Colorizer();
			newObject->setColor( black );
			startConstructionMode(  i18n( "Apply black to an object" ) );
			break;
		case ID_buttonDarkGray:
			newObject = new Colorizer();
			newObject->setColor( darkGray );
			startConstructionMode(  i18n( "Apply dark gray to an object" ) );
			break;
		case ID_buttonLightGray:
			newObject = new Colorizer();
			newObject->setColor( lightGray );
			startConstructionMode(  i18n( "Apply light gray to an object" ) );
			break;
		case ID_buttonWhite:
			newObject = new Colorizer();
			newObject->setColor( white );
			startConstructionMode(  i18n( "Apply white to an object" ) );
			break;
		case ID_buttonBlue:
			newObject = new Colorizer();
			newObject->setColor( blue );
			startConstructionMode(  i18n( "Apply blue to an object" ) );
			break;
		case ID_buttonRed:
			newObject = new Colorizer();
			newObject->setColor( red );
			startConstructionMode(  i18n( "Apply red to an object" ) );
			break;
		case ID_buttonGreen:
			newObject = new Colorizer();
			newObject->setColor( darkGreen );
			startConstructionMode(  i18n( "Apply green to an object" ) );
			break;
		case ID_buttonThinLine:
			newObject = new Thicker();
			newObject->setSize( 5 );
			newObject->setWidth( 1 );
			startConstructionMode(  i18n( "Change the size of an object to small" ) );
			break;
		case ID_buttonMiddleLine:
			newObject = new Thicker();
			newObject->setSize( 11 );
			newObject->setWidth( 3 );
			startConstructionMode(  i18n( "Change the size of an object to medium" ) );
			break;
		case ID_buttonThickLine:
			newObject = new Thicker();
			newObject->setSize( 21 );
			newObject->setWidth( 5 );
			startConstructionMode(  i18n( "Change the size of an object to large" ) );
			break;
		case ID_buttonPointxy:
			CoordinatesDialog *coords = new CoordinatesDialog( 0, 0, true,0 );
			//coords->X->setRange( - MetricsCenter::xMax, MetricsCenter::xMax, 1, false );
			//coords->Y->setRange( - MetricsCenter::yMax, MetricsCenter::yMax, 1, false );
			coords->X->setFocus();
		  if ( ( coords->exec() ) )
			{
				Coordinates coord1( coords->X->text().toDouble(), coords->Y->text().toDouble() );
				MetricsCenter::mapGridToCanvas( coord1 );
				newObject = new Point();
				startConstructionMode( i18n( "Draw a point at (x;y)" ) );
				insertObject( coord1 );
			}
			else
			{
				startMoveMode();
			}
			delete coords;
			break;
	}
}
